* {
    box-sizing: border-box;
}
html, body {
    padding: 0;
    margin: 0;
    height: 100vh;
    width: 100vw;
    /* height: 100%;
    width: 100%; */
    overflow-x: hidden;
    overflow-y: auto;
}

body {
    background-color: #f5f5f9;
    user-select: none;
}

/* Chat container */
.chat-container {
    height: 100% !important;
    /* width: 99vw; */
    padding: 0;
    margin: 0;
    overflow: auto;
    height: 500px;
}

/* Chat message */
.chat-message {
    padding: 5px;
    padding-top: 19px;
    padding-bottom: 7px;
    margin: 0;
    margin-bottom: 1.1rem;
    background-color: #fff;
    border-radius: 10px;
    position: relative;
}

.chat-message-msg {
    /* white-space: pre-wrap; */
    user-select: text;
    padding: 0;
    margin: 0;
}

.chat-message-msg p {
    font-size: 0.9rem;
    /* line-height: 0.98rem; */
}

.chat-message-msg pre {
    font-size: 0.89rem;
    background-color: #f5f5f9;
    border-radius: 2px;
    /* padding: 4px;
    margin: 4px; */
    margin-top: 7px;
    margin-bottom: 10px;
    width: auto;
}

.hljs {
    padding: 0.5em !important;
}

.chat-message-msg p code {
    background-color: #f5f5f9;
    border-radius: 2.5px;
    padding: 1.4px 1.2px 1.4px 1.2px;
}

.chat-message-msg p {
    padding: 1px;
    margin: 1px;
}

/* Chat message from self */
.chat-message-self {
    background-color: #dcf8c6;
}

/* Chat message username */
.chat-message-username {
    user-select: text;
    font-size: 12px;
    color: #C0C0C0;
    position: absolute;
    bottom: -20px;
    left: 2;
    top: 0;
}

/* Chat message time */
.chat-message-time {
    font-size: 12px;
    color: #999;
    position: absolute;
    bottom: -10px;
    right: 0;
}


/* Chat message from self username */
/* .chat-message-username-self {
left: auto;
right: 0;
} */

/* Chat message from self time */
/* .chat-message-time-self {
left: 0;
right: auto;
} */